function out=gd_randomize(in,ic,inj)
% randomization of a gd (or bsd or array)
%
%   out=gd_randomize(in,ic)
%  
%   in    input gd (or bsd or array)
%   ic    = 1 y permutation
%           2 normal white noise
%           3 normal white noise with holes
%   inj   (if present) software injection [freq amp phase]; freq as seen in
%          the band (0->1), phase in deg

% Snag Version 2.0 - Apr 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

out=in;
if ~isnumeric(in)
    in=y_gd(in);
end

n=length(in);
icreal=isreal(in);
iii=find(abs(in));
amp=mean(abs(in(iii)));

if exist('inj')
    if length(inj) == 2
        inj(3)=0;
    end
    if length(inj) == 1
        inj(2)=1;
        inj(3)=0;
    end
    if icreal
        sinj=inj(2)*sin((0:n-1)*2*pi*inj(1)+inj(3)*pi/180);
    else
        sinj=inj(2)*exp(-1j*(0:n-1)*2*pi*inj(1)+inj(3)*pi/180);
    end
else
    sinj=zeros(1,n);
end

switch ic
    case 1
        ii=randperm(n);
        in=in(ii);
        in=in*amp;
        in=in+sinj';
    case 2
        in=randn(n,1);
        if ~icreal
            in=in+1j*randn(n,1);
        end
        in=in*amp;
        in=in+sinj';
    case 3
        ii=ones(n,1);
        iii=find(abs(in) == 0);
        in=randn(n,1);
        if ~icreal
            in=in+1j*randn(n,1);
        end
        in=in*amp;
        in=in+sinj';
        in(iii)=0;
end

if isnumeric(out)
    out=in;
else
    out=edit_gd(out,'y',in);
end