function out=NC_freq(time,N,dt,fr,dfr,alpha,delta,coord)
% Computes the changing frequency of a source
%
%   out=NC_freq(time,N,dt,fr,dfr,alpha,delta,coord)
%
%   time           initial date-time (mjd)
%   dt             sampling time
%   N              number of times
%   fr             original frequency
%                  fr(1) initial frequency
%                  if dim(fr) = 1, costant frequency
%                  if dim(fr) < 6, fr(2->5) spin-down parameters
%                  otherwise dim(fr) = dim(time)
%   dfr            frequency resolution
%   alpha,delta    source coordinates (in degrees, the type defined by coord)
%   coord          = 0 -> equatorial (def), = 1 -> ecliptic
%
%   out.fr         output frequency
%   out.dk         frequency shift

% Snag Version 2.0 - September 2021
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio, L.Pierini and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

if ~exist('coord','var')
    coord=0;
end
n=length(fr);n
t=time+(0:N-1)*dt;
tt=t*86400;
tt0=(t-time)*86400;
out.t=t;
out.fr0=fr(1);

if n == 1
    disp('1')
    fr(1:N)=fr;
elseif n < 6
    disp('2')
    nord=n-1;
    sdpar(1:nord)=fr(2:n);

    sd=zeros(1,N);

%         nDT=round(DT*86400/dt);

    nord=length(sdpar);
    fac=1; size(t),size(sd)

    for i = 1:nord
        fac=fac*i;
%             sd=sd+(sdpar(i)*(((0:n-1)+nDT)*dt).^i)/fac;
        sd=sd+sdpar(i)*(tt0.^i)/fac;
    end

    fr=sd*0+fr(1);
    fr=fr-sd; size(fr)
    out.sd=sd;
else
        disp('3')
end

fr0=fr(1);

fr1=doppler_norot(t,1,alpha,delta,coord);
out.fr1=fr1;
[einst,d]=einst_effect(t);
out.einst=einst;


fr=fr(:);
einst=einst(:);
out.fr=fr.*fr1.*einst;

out.shift=round((out.fr-fr0)/dfr);