function [sids,bsdsstr]=NC_sid_sweep_multi(bsdsstr,direc,freq,NCcom)
% multi antenna sid_sweep candidates
%
%   sids=sid_sweep_multi(bsdsstr,direc,freq,NCcom)
%
%   bsdsstr  bsd search structure array (with addr,ant,runame  as for bsd_lego)
%             if it is a cell array containing bsds, use them
%   direc    direction structure
%   freq     candidate frequency;
%             if 2-dim freq(2), spin-down
%             if 3-dim freq(3) is the semiband; def semiband 0.5 Hz
%   NCcom
%      sband    search band (in units of 1/SD; default 20) sband=0 -> 20
%      interl   interlacing delay (in 1/SD); default sband/2, if sband = 20, interl = 5
%      enl      enlargement factor (def 1)
%      nsid     number of sidereal bins (def or 0 = round(SD/outsid.DT))
%
%      sol      if exists and >0 -> also solar
%
%      nweek    if present and >0, t-fr mode, n week for pieces (typically 1)
%      dweek    week interlacing delay (<= nweek, def nweek/2, =nweek or 0 no interlacing)
%
%      sdcorr   = 1 spin-down correction (def 0; used in sid_sweep_multi and possibly elsewhere)
% 
%      out.ff   1 all, or indices [ini fin]
%      out.POW  1 all, or indices [ini fin]

% Snag Version 2.0 - Apr 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

%% base parameters

if ~exist('NCcom','var')
    NCcom=struct();
end

if ~isfield(NCcom,'sdcorr')
    NCcom.sdcorr=0;
end

if ~exist('nsid','var')
    nsid=0;
end

if length(freq) == 1
    freq(2)=0;
end

if length(freq) <= 2
    freq(3)=0.5;
end

disp('in NC_sid_sweep_multi NCcom:')
disp(NCcom)

%% data bsds

n=length(bsdsstr);
if ~iscell(bsdsstr)
    for k = 1:n
        kk=num2str(k);
        addr=bsdsstr(k).addr;
        ant=bsdsstr(k).ant;
        runame=bsdsstr(k).runame;
        band=freq(1)+[-0.5 0.5];
        eval(['bsdsstr1{' kk '}=bsd_lego(addr,ant,runame,1,band,2);'])
    end
    bsdsstr=bsdsstr1;
    save('bsdscell','bsdsstr')
end

for k = 1:n
    [~,pars]=is_bsd(bsdsstr{k});
    if k == 1
        tin=pars.tin;
        tfi=pars.tfi;
    else
        tin=min(tin,pars.tin);
        tfi=max(tfi,pars.tfi);
    end
    sidpars.ant{k}=pars.ant;
end

sidpars.tin=tin;
sidpars.tfi=tfi;
sidpars.epoch=floor((tin+tfi)/2);

NCcom.MODE='';

if isfield(NCcom,'sband')
    sband=NCcom.sband;
    if sband == 0
        sband=20;
    end
else
    sband=20;
end

if isfield(NCcom,'interl')
    interl=NCcom.interl;
else
    if sband == 20
        interl=5;
    else
        interl=sband/2;
    end 
end

if isfield(NCcom,'enl')
    enl=NCcom.enl;
else
    enl=1;
end

if isfield(NCcom,'sol')
    if NCcom.sol > 0
        icsol=1;
    end
else
    icsol=0;
end

if NCcom.sdcorr == 0
    direc.df0=0;
    direc.ddf0=0;
end

disp('in NC_sid_sweep_multi NCcom:')
disp(NCcom),direc

%% sid sweeps

for k = 1:n
    fprintf('\n!!!    %s    %s   sdcorr:%d \n\n',sidpars.ant{k},direc.name,NCcom.sdcorr)
%     [bsds_corr{k},frcorr]=bsd_dopp_sd(bsdsstr{k},direc);
    bsds_corr{k}=bsd_dopp_sd(bsdsstr{k},direc);
    bsds_corr{k}=cut_bsd(bsds_corr{k},[tin,tfi],1);
    sids{k}=NC_sid_sweep_base(bsds_corr{k},direc,freq,NCcom);
%     sids{k}.frcorr=frcorr;
end

sids{n+1}=sidpars;