function out=bsd_multiant(bsds_addr_tab,sour,wband,MAcom)
% one or more antennas analysis
%
%   bsds_addr_tab   bsds tab structure as
%                         addr='E:';
%                         bsds_addr_tab(1).addr=addr;
%                         bsds_addr_tab(1).tab=BSD_O3_L;
%                         bsds_addr_tab(2).addr=addr;
%                         bsds_addr_tab(2).tab=BSD_O3_H;
%                         bsds_addr_tab(3).addr=addr;
%                         bsds_addr_tab(3).tab=BSD_O3_V;
%                   or string array, as ["F:";"BSD_O3_L"]
%   sour            candidate source
%   wband           output bandwidth (full), or externally fixed band
%   MAcom           function control (if absent, default)
%      .dt0         base sampling time (def 0.1)
%      .fixfreq     1 fix externally the frequency band, or 0 (def)
%      .equifreq    1 (def) or 0; also equi_T_ini: use of antenna set
%      .orthoband   1 (def) or 0 no; 2 quasi-orthoband
%      .nocorr      no correction 1 or 0 (def)
%      .noT_mean    source reference time at beginning
%      .rawout      output also of non-corrected bsd
%      .specres     spectral resolution (0 no spectra)
%      .frshift     frequency shift the data (changes also sour)
%      .

% Snag Version 2.0 - April 2021
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni and S. Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Sapienza University - Rome

SD=86164.09053083288;

if ~exist('MAcom','var')
    MAcom.dt0=0.1;
end

dt0=MAcom.dt0;

MAcom.wband=wband;

if ~isfield(MAcom,'fixfreq')
    MAcom.fixfreq=0;
end

if ~isfield(MAcom,'equifreq')
    MAcom.equifreq=1;
end

if ~isfield(MAcom,'orthoband')
    MAcom.orthoband=1;
end

if ~isfield(MAcom,'noT_mean')
    MAcom.noT_mean=0;
end

if ~isfield(MAcom,'nocorr')
    MAcom.nocorr=0;
end

parants=check_bsdsstr(bsds_addr_tab,dt0);
nant=parants.nant;

if ~isfield(MAcom,'specres')
    MAcom.specres=2;
end

if ~isfield(MAcom,'rawout')
    MAcom.rawout=0;
end

if ~isfield(MAcom,'frshift')
    MAcom.frshift=0;
end

parants.frshift=MAcom.frshift;
T=parants.T_mean;
if MAcom.noT_mean == 1
    T=parants.T_ini;
end

parants.prlemod=MAcom.orthoband;

parants.equifreq=MAcom.equifreq;
out.parants=parants;

sour=new_posfr(sour,T);
if MAcom.fixfreq == 0
    freq=[sour.f0-wband/2 sour.f0+wband/2]+MAcom.frshift;
else
    freq=wband;
end
MAcom.freq=freq;
out.MAcom=MAcom;

for k = 1:nant
    bat=bsds_addr_tab(k);
    [bsd_out,BSD_tab_out,stpar]=bsd_newlego(bat.addr,bat.tab,0,freq,2,parants);
    stPar{k}=stpar;
    if MAcom.rawout
        bsdsrawcell{k}=bsd_out;
    end
    if MAcom.nocorr == 0
        bsd_out=bsd_dopp_sd(bsd_out,sour);
    end
    bsdscell{k}=bsd_out;
    if MAcom.specres > 0
        specs{k}=bsd_pows(bsd_out,MAcom.specres);
        xs=sour.f0+[-2 -1 0 1 2]/SD;
        figure,semilogy(specs{k}),plot_lines(xs,specs{k},'g'),grid on
    end
end

out.stPar=stPar;
out.bsdscell=bsdscell;
out.specs=specs;
if MAcom.rawout
    out.bsdsrawcell=bsdsrawcell;
end