function out=NC4_read(fil,kcand,typ,plt)
% reads data from NC3 or NC4 file 
%
%    out=NC4_read(fil,kcand,typ,plt)
%
%   fil      type NC3 or NC4 file
%   kcand    candidate number (0 or absent, list)
%   typ      1 only frequency, 2 time frequency
%   plt      plot type (def no)

% Snag Version 2.0 - May 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

load(fil)

ncand=length(outmul.cand);
fprintf('\n %d candidates found\n',ncand);
nant=length(outmul.sids{1})-1; nant,outmul
fprintf(' %d antennas ',nant);
for i = 1:nant
    fprintf(' %s ',outmul.sids{1}{nant+1}.ant{i})
    ant{i}=outmul.sids{1}{nant+1}.ant{i};
end
fprintf('\n\n')

if ~exist('kcand','var')
    kcand=0;
end
if ~exist('plt','var')
    plt=0;
end

if kcand == 0
    cands=outmul.cand;
    fprintf('   Name        a           d            fr             sd           h\n')
    for i = 1:ncand
        cc=cands{i};
        if ~isfield(cc,'name')
            cc.name=sprintf('cand %d',i);
        end
        fprintf(' %s    %.3f     %.3f     %f    %.3e    %.2e\n',cc.name,cc.a,cc.d,cc.f0,cc.df0,cc.h)
    end
    out.cands=cands;
else
    cc=outmul.cand{kcand};
    out.cand=cc;
    if ~isfield(cc,'name')
        cc.name=sprintf('cand %d',kcand);
    end
    ccname=underscore_man(cc.name);
    sids=outmul.sids{kcand};
    switch typ
        case 1
            [n1,n2]=size(sids{1}.sidsig);
            out.fr=sids{1}.fr;
            out.sidsig=cell(1,nant);
            out.sidnois=cell(1,nant);
            out.sidzer=cell(1,nant);
            for i = 1:nant
                out.sidsig{i}=gd(sids{i}.sidsig);
                out.sidsig{i}=edit_gd(out.sidsig{i},'ini',sids{1}.fr(1),'dx',sids{1}.fr(2)-sids{1}.fr(1));
                out.sidnois{i}=gd(sids{i}.sidnois);
                out.sidnois{i}=edit_gd(out.sidnois{i},'ini',sids{1}.fr(1),'dx',sids{1}.fr(2)-sids{1}.fr(1));
                out.sidzer{i}=gd(sids{i}.sidzer);
                out.sidzer{i}=edit_gd(out.sidzer{i},'ini',sids{1}.fr(1),'dx',sids{1}.fr(2)-sids{1}.fr(1));
            end
            switch plt
                case 1
                    figure
                    for i = 1:nant
                        semilogy(out.sidsig{i}),hold on,grid on
                    end
                    title([ccname ' sig']),xlabel('Hz')
                    plot_lines(cc.f0,out.sidsig{i})
                    figure
                    for i = 1:nant
                        semilogy(out.sidnois{i}),hold on,grid on
                    end
                    title([ccname ' nois']),xlabel('Hz')
                    plot_lines(cc.f0,out.sidsig{i})
                    figure
                    for i = 1:nant
                        semilogy(out.sidzer{i}),hold on,grid on
                    end
                    title([ccname ' zer']),xlabel('Hz')
                    plot_lines(cc.f0,out.sidsig{i})
                case 2
                    for i = 1:nant
                        figure
                        semilogy(out.sidsig{i}),hold on,grid on
                        semilogy(out.sidnois{i})
                        semilogy(out.sidzer{i})
                        title([ccname ' sig,nois,zer antenna ' ant{i}])
                    end
            end
        case 2
            [n1,n2]=size(sids{1}.sidsigs);
            out.fr=sids{1}.fr;
            dweek=sids{1}.dweek;
            out.sidsigs=cell(1,nant);
            out.sidnoiss=cell(1,nant);
            out.sidzers=cell(1,nant);
            for i = 1:nant
                out.sidsigs{i}=gd2(sids{i}.sidsigs);
                out.sidsigs{i}=edit_gd2(out.sidsigs{i},'ini',0,'dx',dweek*7,'ini2',sids{1}.fr(1),'dx2',sids{1}.fr(2)-sids{1}.fr(1));
                out.sidnoiss{i}=gd2(sids{i}.sidnoiss);
                out.sidnoiss{i}=edit_gd2(out.sidnoiss{i},'ini',0,'dx',dweek*7,'ini2',sids{1}.fr(1),'dx2',sids{1}.fr(2)-sids{1}.fr(1));
                out.sidzers{i}=gd2(sids{i}.sidzers);
                out.sidzers{i}=edit_gd2(out.sidzers{i},'ini',0,'dx',dweek*7,'ini2',sids{1}.fr(1),'dx2',sids{1}.fr(2)-sids{1}.fr(1));
                out.projsigs{i}=proj_gd2(2,out.sidsigs{i});
                out.projnois{i}=proj_gd2(2,out.sidnoiss{i});
                out.projzers{i}=proj_gd2(2,out.sidzers{i});
            end
            if plt > 0
                for i = 1:nant
                    plot(out.sidsigs{i}),title([ccname ' sig antenna ' ant{i}])
                    xlabel('days'),ylabel('Hz')
                    plot(out.sidnoiss{i}),title([ccname ' nois antenna ' ant{i}])
                    xlabel('days'),ylabel('Hz')
                    plot(out.sidzers{i}),title([ccname ' zer antenna ' ant{i}])
                    xlabel('days'),ylabel('Hz')
                    figure,semilogy(out.projsigs{i}),title([ccname ' sig antenna ' ant{i}]),xlabel('Hz'),grid on
                    plot_lines(cc.f0,out.projsigs{i},'r')
                    figure,semilogy(out.projnois{i}),title([ccname ' nois antenna ' ant{i}]),xlabel('Hz'),grid on
                    plot_lines(cc.f0,out.projnois{i},'r')
                    figure,semilogy(out.projzers{i}),title([ccname ' zer antenna ' ant{i}]),xlabel('Hz'),grid on
                    plot_lines(cc.f0,out.projzers{i},'r')
                end
            end
    end
end