function outmul=NC_crea_DC4(bsds_addr_tab,cands,header,tail,NCcom)
% creates a type 4 non-coherent DB
% 
%     outmul=NC_crea_DC4(bdsstr,cands,header,tail,NCcom)
%
%   bdsstr   (as for bsd_equilego) example:
%                 bsds_addr_tab(1).addr='K:';
%                 bsds_addr_tab(1).tab=BSD_O3_L;
%                 bsds_addr_tab(2).addr='K:';
%                 bsds_addr_tab(2).tab=BSD_O3_H;
%                 bsds_addr_tab(3).addr='K:';
%                 bsds_addr_tab(3).tab=BSD_O3_V;
%   cands    list of sources (cell array)
%   header   of the files (ex: 'hinj')
%   tail     filnam tail
%
%   NCcom
%      frbase   bsd frequency base (def 10)
%      wband    sub-band division (0.5,1,2,5,10 Hz; default 1 Hz)
%      sband    search band (in units of 1/SD; default 20) sband=0 -> 20
%      interl   interlacing delay (in 1/SD); default sband/2, if sband = 20, interl = 5
%      enl      enlargement factor (def 1)
%      nsid     number of sidereal bins (def or 0 = round(SD/outsid.DT))
%
%      sol      if exists and >0 -> also solar (NYI)
%      checksolar  if exist and = 1, substitutes SD with SolD
%                  if > 1, substitutes SD with checksolar
%
%      nweek    if present and >0, t-fr mode, n week for pieces (typically 1)
%      dweek    week interlacing delay (<= nweek, def nweek/2, =nweek or 0 no interlacing)
%
%      sdcorr   = 1 spin-down correction (def 0; used in sid_sweep_multi and possibly elsewhere)
%
%      equilego 1 or 0 (def)

% Snag Version 2.0 - May 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

tic
out.start=datetime('now');

if ~exist('NCcom','var')
    NCcom=struct();
end

NCcom.nweek=1;

if isfield(NCcom,'frbase')
    frbase=NCcom.frbase;
else
    frbase=10;
end

NCcom

ncands=length(cands);

filnam=NC_filnam(4,header,'cand',[],[],tail)

% tab=bsds_addr_tab(1).tab;
% t_ini=tab.t_ini(1);
out=check_bsdsstr(bsds_addr_tab);
T_ini=out.T_ini;

for i = 1:ncands
    cand=new_posfr(cands{i},T_ini);
    [sids{i},bsds]=NC_sid_sweep_multi(bsds_addr_tab,cand,cand.f0,NCcom);
    eval(['save(''BSDs_' cands{i}.name ''',''bsds'',''cand'',''-v7.3'');'])
    if i == 1  
%         outmul.run=sids{1,1}{1,1}.run;
        outmul.t0=sids{1,1}{1,1}.t0+sids{1,1}{1,1}.nweek*7/2;
        outmul.DT=sids{1,1}{1,1}.DT;
        outmul.DFR=sids{1,1}{1,1}.DFR;
        outmul.band=sids{1,1}{1,1}.inifr+[0 sids{1,1}{1,1}.bandw];
        outmul.frdel=sids{1,1}{1,1}.frdel;
    end
    str.Dtime=toc
    outmul.cand{i}=cand;
    outmul.sids{i}=sids{i};
end

outmul.Dtime=toc
save(filnam,'outmul','-v7.3')