function sidsw=NC_sid_sweep(addr,tab,direc,freq,NCcom)
% sid sweep on a band 
%
%   sidsw=NC_sid_sweep(addr,tab,direc,freq,NCcom)
%
%   addr,tab  as for bsd_equilego
%   direc   direction structure ('nodirec' direction absent)
%   freq    a frequency inside the bsd base band (10 Hz)
%
%   NCcom
%      frbase   bsd frequency base (def 10)
%      wband    sub-band division (0.5,1,2,5,10 Hz; default 1 Hz)
%      sband    search band (in units of 1/SD; default 20) sband=0 -> 20
%      interl   interlacing delay (in 1/SD); default sband/2, if sband = 20, interl = 5
%      enl      enlargement factor (def 1)
%      nsid     number of sidereal bins (def or 0 = round(SD/outsid.DT))
%
%      sol      if exists and >0 -> also solar (NYI)
%      checksolar  if exist and = 1, substitutes SD with SolD
%                  if > 1, substitutes SD with checksolar
%
%      nweek    if present and >0, t-fr mode, n week for pieces (typically 1)
%      dweek    week interlacing delay (<= nweek, def nweek/2, =nweek or 0 no interlacing)
%
%      sdcorr   = 1 spin-down correction (def 0; used in sid_sweep_multi and possibly elsewhere)

% Snag Version 2.0 - May 2020
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni, S.D'Antonio and S.Frasca - ser.fras@gmail.com
% Department of Physics - Sapienza University - Rome

SD=86164.09053083288;
SOL=86400;
tic

if ~exist('NCcom','var')
    NCcom=struct();
    NCcom.nweek=0;
end

if isfield(NCcom,'nweek')
    nweek=NCcom.nweek;
else
    nweek=0;
end

if isfield(NCcom,'frbase')
    frbase=NCcom.frbase;
else
    frbase=10;
end

if strcmp(direc,'nodirec') && ~isfield(NCcom,'wband')
    NCcom.wband=frbase;
end

if isfield(NCcom,'wband')
    wband=NCcom.wband;
else
    wband=1;
end

if ~isfield(NCcom,'sdcorr')
    NCcom.sdcorr=0;
end

if NCcom.sdcorr == 0
    if isstruct(direc)
        direc.df0=0;
        direc.ddf0=0;
    end
end

sidsw.frbase=frbase;
sidsw.wband=wband;
sidsw.table=inputname(2);

nwband=frbase/wband;

frin=floor(freq/frbase)*frbase;

sidsig0=[];
sidnois0=[];
sidzer0=[];
sidsigs0=[];
sidnoiss0=[];
sidzers0=[];

for i = 1:nwband
    disp('++++++++++++++++++++++++')
    band=frin+[i-1 i]*wband;band,[mean(band) 0 mean(band)-band(1)]
    band=round(band); % per evitare casini, ma in generale è da togliere

    bsd_corr=NC_bsdcorr(addr,tab,band,direc);
    outsid=NC_sid_sweep_base(bsd_corr,direc,[mean(band) 0 mean(band)-band(1)],NCcom)
    
    if i == 1
        frin=outsid.fr(1);
        DFR=outsid.DFR;
        sidsw.ant=outsid.ant;
        sidsw.t0=outsid.t0;
        sidsw.band=frin+[0 frbase];
        sidsw.DFR=DFR;
        sidsw.frdel=outsid.frdel;
        sidsw.SSB=outsid;
%         sidsw.SSB.fr=[];
        sidsw.SSB.Y2=[];
        sidsw.SSB.sidsig=[];
        sidsw.SSB.sidnois=[];
        sidsw.SSB.sidzer=[];
        sidsw.SSB.sidsigs=[];
        sidsw.SSB.sidnoiss=[];
        sidsw.SSB.sidzers=[];
    end
    if nweek == 0
        sidsig0=[sidsig0 outsid.sidsig];
        sidnois0=[sidnois0 outsid.sidnois];
        sidzer0=[sidzer0 outsid.sidzer];
    else
        sidsig0=[sidsig0 outsid.sidsig];
        sidnois0=[sidnois0 outsid.sidnois];
        sidzer0=[sidzer0 outsid.sidzer];
        sidsigs0=[sidsigs0 outsid.sidsigs];
        sidnoiss0=[sidnoiss0 outsid.sidnoiss];
        sidzers0=[sidzers0 outsid.sidzers];
    end
%     sidsw.bsds{i}=bsd_corr;
    
    ttt=toc;
    sidsw.ttt=ttt;
    fprintf(' --------------> %d  %f s ----------------\n',i,ttt)
end

if nweek == 0
    sidsw.sidsig=sidsig0;
    sidsw.sidnois=sidnois0;
    sidsw.sidzer=sidzer0;
else
    sidsw.sidsig=sidsig0;
    sidsw.sidnois=sidnois0;
    sidsw.sidzer=sidzer0;
    sidsw.sidsigs=sidsigs0;
    sidsw.sidnoiss=sidnoiss0;
    sidsw.sidzers=sidzers0;
end