function prle=pre_equilego(bandin,Dt_max,prlemod,dt0)
% Basic computations for equilego
%
%    bandin   requested band [frmin frmax]
%    Dt_max   max bsd time length
%    prlemod  mode; 0 default, 1 orthoband,...)
%    dt0      basic bsd sampling time (def 0.1)

% Snag Version 2.0 - April 2021
% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% by O.J.Piccinni and S. Frasca - sergio.frasca@roma1.infn.it
% Department of Physics - Sapienza University - Rome

if ~exist('prlemod','var')
    prlemod=1;
end

if ~exist('dt0','var')
    dt0=0.1;
end

%---------- part 1 - base
prle.basefr=floor(bandin(1)*dt0)/dt0; prlemod
prle.endfr=ceil(bandin(2)*dt0)/dt0;
nband=(prle.endfr-prle.basefr)*dt0;
prle.nband=nband;
if nband > 2
    disp(' *** band too large !')
    return
end
prle.dt00=dt0; % basic st
dt0=dt0/nband; % basic st/nband
prle.dt0=dt0;

%---------- part 2 - frequency
nsampmax=round(Dt_max*86400/dt0+1);
prle.nsampmax=nsampmax;

prle.orthoband='NO ORTHOBAND';
prle.quasiorthoband='NO QUASI-ORTHOBAND';
prle.prlemod=prlemod;
xfact0=1/((bandin(2)-bandin(1))*dt0);
fact0=round(xfact0);parants
bandw0=1/(fact0*dt0);
switch prlemod
    case 1
%         ob=base_orthobands(bandin,dt0);
        ob=bsd_orthoband(bandin,dt0,nsampmax)
        bandout=ob.bandout;
        prle.orthoband=ob;
    case 2
        qob=base_quasiorthoband(bandin,dt0);
        bandout=qob.bandout;
        prle.quasiorthoband=qob;
    case 0
        bandw=diff(bandin);
        bandw=1/(dt0*round(1/(dt0*bandw)));
        bandout=(bandin(1)+bandin(2))/2+[-bandw/2 bandw/2];
end

prle.bandin=bandin;
prle.bandout=bandout;
bandw=bandout(2)-bandout(1);
prle.bandw=bandw;
xfact=1/(bandw*dt0);
fact=round(xfact);
prle.xfact=xfact;
prle.fact=fact;
prle.dt1=dt0*fact;
NRL=ceil(nsampmax/fact)*fact; % rounded length
prle.NRL=NRL;
dfr=1/(dt0*NRL);
prle.dfr=dfr;
lenout=NRL/fact;
prle.lenout=lenout;

prle.iniband=round((bandout(1)-prle.basefr)/dfr)+1;
prle.finband=prle.iniband+lenout-1;
prle.outband=prle.basefr+[prle.iniband prle.finband]*dfr+[-dfr 0];

prle.bounderr=prle.outband-bandin;

%---------- part 3 - time

%     [tab_out,stpar]=bsd_subtab(partab.tab{k},0,prle.outband,0.1);

% prle.=;
% prle.=;
% prle.=;
% prle.=;
% prle.=;
