function [S,SP,s,sp,ssp,S1,SP1,SS1,v1]=SidPat_from5v(v,phi)
% computes the sidereal pattern and his spectrum
%
%    v      5-vect
%    phi    two equivalence parameter phases in deg [phi0 phi1]

% Part of Snag toolbox - Signal and Noise for Gravitational Antennas
% v1 April 2022
% by Sergio Frasca - ser.fras@gmail.com

if exist('phi','var')
    v=transf_5vec(v,phi(1),phi(2));
end
v1=v;

N=480;

% Mode 1

SP=abs(sidresp_5vec(v,N)).^2;
SS=fft(y_gd(SP))/N;
S(1)=SS(1);
S(2)=SS(2)+SS(N);
S(3)=SS(3)+SS(N-1);
S(4)=SS(4)+SS(N-2);
S(5)=SS(5)+SS(N-3);

% Mode 2

ss=conv(v,conj(flip(v)));

ssp=0;
sp=0;
t=(0:N-1)*2*pi/N;

for i = -4:4
    ssp=ssp+exp(1j*i*t)*ss(i+5); 
end

ssp=real(ssp);

s(1)=ss(5);
s(2:5)=2*real(ss(6:9));

for i = 0:4
    sp=sp+cos(i*t)*s(i+1); 
end
% Mode 3

SS1(1)=sum(abs(v).^2);
SS1(2)=v(1)*conj(v(2))+v(2)*conj(v(3))+v(3)*conj(v(4))+v(4)*conj(v(5));
SS1(3)=v(1)*conj(v(3))+v(2)*conj(v(4))+v(3)*conj(v(5));
SS1(4)=v(1)*conj(v(4))+v(2)*conj(v(5));
SS1(5)=v(1)*conj(v(5));
SS1(6)=conj(v(1))*v(2)+conj(v(2))*v(3)+conj(v(3))*v(4)+conj(v(4))*v(5);
SS1(7)=conj(v(1))*v(3)+conj(v(2))*v(4)+conj(v(3))*v(5);
SS1(8)=conj(v(1))*v(4)+conj(v(2))*v(5);
SS1(9)=conj(v(1))*v(5);

S1(1)=SS1(1);
S1(2)=SS1(2)+SS1(6);
S1(3)=SS1(3)+SS1(7);
S1(4)=SS1(4)+SS1(8);
S1(5)=SS1(5)+SS1(9);

SP1=0;
SSP1=0;
for i = 0:4
    SP1=SP1+cos(i*t)*S1(i+1);
    SSP1=SSP1+exp(1j*i*t)*SS1(i+5);
end

T=t*12/pi;

figure,plot(SP),hold on,plot(T,sp,'g'),plot(T,SP1,'--r'),plot(T,ssp,'--m'),grid on,title('SP, SP1(r), sp(g),ssp(m)')

figure,plot(SSP1),grid on,hold on,plot(SSP1(1),'Or'),plot(SSP1(N),'Xg')